DeveloperKnowledge

Struct DeveloperKnowledge 

pub struct DeveloperKnowledge { /* private fields */ }
Implements a client for the Developer Knowledge API.

Example

async fn sample(
   document_id: &str,
) -> anyhow::Result<()> {
    let client = DeveloperKnowledge::builder().build().await?;
    let response = client.get_document()
        .set_name(format!("documents/{document_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

The Developer Knowledge API provides programmatic access to Google’s public developer documentation, enabling you to integrate this knowledge base into your own applications and workflows.

The API is designed to be the canonical source for machine-readable access to Google’s developer documentation.

A typical use case is to first use DeveloperKnowledge.SearchDocumentChunks to find relevant page URIs based on a query, and then use DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments to fetch the full content of the top results.

All document content is provided in Markdown format.

Configuration

To configure DeveloperKnowledge use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

DeveloperKnowledge holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap DeveloperKnowledge in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl DeveloperKnowledge

pub fn builder() -> ClientBuilder

Returns a builder for DeveloperKnowledge.

let client = DeveloperKnowledge::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: DeveloperKnowledge + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn search_document_chunks(&self) -> SearchDocumentChunks

Searches for developer knowledge across Google’s developer documentation. Returns DocumentChunks based on the user’s query. There may be many chunks from the same Document. To retrieve full documents, use DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments with the DocumentChunk.parent returned in the SearchDocumentChunksResponse.results.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_developers_knowledge_v1::Result;
async fn sample(
   client: &DeveloperKnowledge
) -> Result<()> {
    let mut list = client.search_document_chunks()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_document(&self) -> GetDocument

Retrieves a single document with its full Markdown content.

Example
use google_developers_knowledge_v1::Result;
async fn sample(
   client: &DeveloperKnowledge, document_id: &str
) -> Result<()> {
    let response = client.get_document()
        .set_name(format!("documents/{document_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn batch_get_documents(&self) -> BatchGetDocuments

Retrieves multiple documents, each with its full Markdown content.

Example
use google_developers_knowledge_v1::Result;
async fn sample(
   client: &DeveloperKnowledge
) -> Result<()> {
    let response = client.batch_get_documents()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn answer_query(&self) -> AnswerQuery

Answers a query using grounded generation.

Example
use google_developers_knowledge_v1::Result;
async fn sample(
   client: &DeveloperKnowledge
) -> Result<()> {
    let response = client.answer_query()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}