#[non_exhaustive]pub struct AnswerCitation {
pub start_index: i32,
pub end_index: i32,
pub sources: Vec<CitationSource>,
/* private fields */
}Expand description
Citation info for a segment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_index: i32Output only. Indicates the start of the segment, measured in bytes (UTF-8 unicode), inclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.
end_index: i32Output only. Indicates the end of the segment, measured in bytes (UTF-8 unicode), exclusive. If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.
sources: Vec<CitationSource>Output only. Contains citation sources for the attributed segment.
Implementations
Sourceimpl AnswerCitation
impl AnswerCitation
Sourcepub fn set_start_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_start_index<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_end_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_end_index<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_sources<T, V>(self, v: T) -> Self
pub fn set_sources<T, V>(self, v: T) -> Self