#[non_exhaustive]pub enum DocumentView {
Unspecified,
Basic,
Full,
Content,
UnknownValue(UnknownValue),
}Expand description
Specifies which fields of the Document are included.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default / unset value. See each API method for its default value if DocumentView is not specified.
Basic
Includes only the basic metadata fields:
nameuridata_sourcetitledescriptionupdate_timeviewcontent_length_bytes
This is the default of view for DeveloperKnowledge.SearchDocumentChunks.
Full
Includes all Document fields.
Content
Includes the DOCUMENT_VIEW_BASIC fields and the content field.
This is the default of view for DeveloperKnowledge.GetDocument and DeveloperKnowledge.BatchGetDocuments.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DocumentView::value or DocumentView::name.
Implementations