DocumentChunk

Struct DocumentChunk 

#[non_exhaustive]
pub struct DocumentChunk { pub parent: String, pub id: String, pub content: String, pub document: Option<Document>, pub relevance_score: Option<f64>, /* private fields */ }
A DocumentChunk represents a piece of content from a Document in the DeveloperKnowledge corpus. To fetch the entire document content, pass the parent to DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Output only. Contains the resource name of the document this chunk is from. Format: documents/{uri_without_scheme} Example: documents/docs.cloud.google.com/storage/docs/creating-buckets

id: String

Output only. Specifies the ID of this chunk within the document. The chunk ID is unique within a document, but not globally unique across documents. The chunk ID is not stable and may change over time.

content: String

Output only. Contains the content of the document chunk.

document: Option<Document>

Output only. Represents metadata about the Document this chunk is from. The DocumentView of this Document message will be set to DOCUMENT_VIEW_BASIC. It is included here for convenience so that clients do not need to call DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments if they only need the metadata fields. Otherwise, clients should use DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments to fetch the full document content.

relevance_score: Option<f64>

Output only. Represents the relevance score of the chunk to the search query. Higher score indicates higher chunk relevance. The score is in range [0.0, 1.0].

Implementations

Source

impl DocumentChunk

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = DocumentChunk::new().set_parent(format!("documents/{document_id}"));
pub fn set_id<T: Into<String>>(self, v: T) -> Self

Sets the value of id.

Example
let x = DocumentChunk::new().set_id("example");
pub fn set_content<T: Into<String>>(self, v: T) -> Self

Sets the value of content.

Example
let x = DocumentChunk::new().set_content("example");
pub fn set_document<T>(self, v: T) -> Self
where T: Into<Document>,

Sets the value of document.

Example
use google_developers_knowledge_v1::model::Document;
let x = DocumentChunk::new().set_document(Document::default()/* use setters */);
pub fn set_or_clear_document<T>(self, v: Option<T>) -> Self
where T: Into<Document>,

Sets or clears the value of document.

Example
use google_developers_knowledge_v1::model::Document;
let x = DocumentChunk::new().set_or_clear_document(Some(Document::default()/* use setters */));
let x = DocumentChunk::new().set_or_clear_document(None::<Document>);
pub fn set_relevance_score<T>(self, v: T) -> Self
where T: Into<f64>,

Sets the value of relevance_score.

Example
let x = DocumentChunk::new().set_relevance_score(42.0);
pub fn set_or_clear_relevance_score<T>(self, v: Option<T>) -> Self
where T: Into<f64>,

Sets or clears the value of relevance_score.

Example
let x = DocumentChunk::new().set_or_clear_relevance_score(Some(42.0));
let x = DocumentChunk::new().set_or_clear_relevance_score(None::<f32>);