SearchDocumentChunksRequest

Struct SearchDocumentChunksRequest 

#[non_exhaustive]
pub struct SearchDocumentChunksRequest { pub query: String, pub page_size: i32, pub page_token: String, pub filter: String, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query: String

Required. Provides the raw query string provided by the user, such as “How to create a Cloud Storage bucket?”.

page_size: i32

Optional. Specifies the maximum number of results to return. The service may return fewer than this value.

If unspecified, at most 5 results will be returned.

The maximum value is 100; values above 100 will be coerced to 100.

page_token: String

Optional. Contains a page token, received from a previous SearchDocumentChunks call. Provide this to retrieve the subsequent page.

filter: String

Optional. Applies a strict filter to the search results. The expression supports a subset of the syntax described at https://google.aip.dev/160.

While SearchDocumentChunks returns DocumentChunks, the filter is applied to DocumentChunk.document fields.

Supported fields for filtering:

  • data_source (STRING): The source of the document, e.g. docs.cloud.google.com. See https://developers.google.com/knowledge/reference/corpus-reference for the complete list of data sources in the corpus.
  • update_time (TIMESTAMP): The timestamp of when the document was last meaningfully updated. A meaningful update is one that changes document’s markdown content or metadata.
  • uri (STRING): The document URI, e.g. <https://docs.cloud.google.com/bigquery/docs/tables>.

STRING fields support = (equals) and != (not equals) operators for exact match on the whole string. Partial match, prefix match, and regexp match are not supported.

TIMESTAMP fields support =, <, <=, >, and >= operators. Timestamps must be in RFC-3339 format, e.g., "2025-01-01T00:00:00Z".

Note: Field names must be in snake_case (e.g., data_source). Values on the right-hand side of filtering expressions must be string literals enclosed in double quotes (e.g., "docs.cloud.google.com").

You can combine expressions using AND, OR, and NOT (or -) logical operators. OR has higher precedence than AND. Use parentheses for explicit precedence grouping.

Examples:

  • data_source = "docs.cloud.google.com" OR data_source = "firebase.google.com"
  • data_source != "firebase.google.com"
  • update_time < "2024-01-01T00:00:00Z"
  • update_time >= "2025-01-22T00:00:00Z" AND (data_source = "developer.chrome.com" OR data_source = "web.dev")
  • uri = https://docs.cloud.google.com/release-notes``

The filter string must not exceed 500 characters; values longer than 500 characters will result in an INVALID_ARGUMENT error.

Implementations

Source

impl SearchDocumentChunksRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_query<T: Into<String>>(self, v: T) -> Self

Sets the value of query.

Example
let x = SearchDocumentChunksRequest::new().set_query("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = SearchDocumentChunksRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = SearchDocumentChunksRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = SearchDocumentChunksRequest::new().set_filter("example");