#[non_exhaustive]pub struct SearchDocumentChunksResponse {
pub results: Vec<DocumentChunk>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for DeveloperKnowledge.SearchDocumentChunks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.results: Vec<DocumentChunk>Contains the search results for the given query. Each DocumentChunk in this list contains a snippet of content relevant to the search query. Use the DocumentChunk.parent field of each result with DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments to retrieve the full document content.
next_page_token: StringOptional. Provides a token that can be sent as page_token to retrieve the
next page. If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl SearchDocumentChunksResponse
impl SearchDocumentChunksResponse
Sourcepub fn set_results<T, V>(self, v: T) -> Self
pub fn set_results<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SearchDocumentChunksResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SearchDocumentChunksResponse
impl Clone for SearchDocumentChunksResponse
Sourcefn clone(&self) -> SearchDocumentChunksResponse
fn clone(&self) -> SearchDocumentChunksResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchDocumentChunksResponse
impl Debug for SearchDocumentChunksResponse
Sourceimpl Default for SearchDocumentChunksResponse
impl Default for SearchDocumentChunksResponse
Sourcefn default() -> SearchDocumentChunksResponse
fn default() -> SearchDocumentChunksResponse
Returns the “default value” for a type. Read more
impl StructuralPartialEq for SearchDocumentChunksResponse