pub trait DeveloperKnowledge:
Debug
+ Send
+ Sync {
// Provided methods
fn search_document_chunks(
&self,
_req: SearchDocumentChunksRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SearchDocumentChunksResponse>>> + Send { ... }
fn get_document(
&self,
_req: GetDocumentRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Document>>> + Send { ... }
fn batch_get_documents(
&self,
_req: BatchGetDocumentsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<BatchGetDocumentsResponse>>> + Send { ... }
fn answer_query(
&self,
_req: AnswerQueryRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<AnswerQueryResponse>>> + Send { ... }
}Expand description
Defines the trait used to implement super::client::DeveloperKnowledge.
Application developers may need to implement this trait to mock
client::DeveloperKnowledge. In other use-cases, application developers only
use client::DeveloperKnowledge and need not be concerned with this trait or
its implementations.
Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.
Provided Methods
Sourcefn search_document_chunks(
&self,
_req: SearchDocumentChunksRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<SearchDocumentChunksResponse>>> + Send
fn search_document_chunks( &self, _req: SearchDocumentChunksRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<SearchDocumentChunksResponse>>> + Send
Sourcefn get_document(
&self,
_req: GetDocumentRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<Document>>> + Send
fn get_document( &self, _req: GetDocumentRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<Document>>> + Send
Implements super::client::DeveloperKnowledge::get_document.
Sourcefn batch_get_documents(
&self,
_req: BatchGetDocumentsRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<BatchGetDocumentsResponse>>> + Send
fn batch_get_documents( &self, _req: BatchGetDocumentsRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<BatchGetDocumentsResponse>>> + Send
Sourcefn answer_query(
&self,
_req: AnswerQueryRequest,
_options: RequestOptions,
) -> impl Future<Output = Result<Response<AnswerQueryResponse>>> + Send
fn answer_query( &self, _req: AnswerQueryRequest, _options: RequestOptions, ) -> impl Future<Output = Result<Response<AnswerQueryResponse>>> + Send
Implements super::client::DeveloperKnowledge::answer_query.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".